==> cherry_flutter-0.0.1.tar.gz: example/lib/demo/popup_menu_box.dart <==
import 'package:cherry_flutter/cherry_flutter.dart';
import 'package:example/widgets/widgets.dart';
import 'package:flutter/material.dart';

class PopupMenuBoxDemo extends StatelessWidget {
  const PopupMenuBoxDemo({Key? key}) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      backgroundColor: Colors.white,
      appBar: AppBar(title: Text('PopupMenuBox Page')),
      body: SingleChildScrollView(
        padding: EdgeInsets.symmetric(horizontal: 20),
        child: Column(
          crossAxisAlignment: CrossAxisAlignment.start,
          children: [
            CommonTitle(title: '默认'),
            PopMenuButtonBox<String>(
              tooltip: 'tooltip',
              child:  Container(
                  width: double.infinity,
                  height: 40,
                  color: Colors.blue,
                  alignment: Alignment.center,
                  child: Text('Popup Menu Box', style: TextStyle(color: Colors.white))
              ),
              itemBuilder: (_) => createPopupMenuStringItem(['1','2','3']),
              onSelected: (val) => print(val),
            )
          ],
        ),
      ),
    );
  }

  List<PopupMenuItem<String>> createPopupMenuStringItem<String>(
      List<String> list) {
    return List.generate(list.length, (index) {
      return PopupMenuItem<String>(
        textStyle: TextStyle(fontSize: 12, color: Colors.black),
        value: list[index],
        height: 40,
        child: Text('${list[index]}'),
      );
    });
  }
}

==> cherry_flutter-0.0.8.tar.gz: example/lib/demo/popup_menu_box.dart <==
import 'package:cherry_flutter/cherry_flutter.dart';
import 'package:example/widgets/widgets.dart';
import 'package:flutter/material.dart';

class PopupMenuBoxDemo extends StatelessWidget {
  const PopupMenuBoxDemo({Key? key}) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      backgroundColor: Colors.white,
      appBar: AppBar(title: Text('PopupMenuBox Page')),
      body: SingleChildScrollView(
        padding: EdgeInsets.symmetric(horizontal: 20),
        child: Column(
          crossAxisAlignment: CrossAxisAlignment.start,
          children: [
            CommonTitle(title: '默认'),
            CHFPopMenuButtonBox<String>(
              tooltip: 'tooltip',
              child:  Container(
                  width: double.infinity,
                  height: 40,
                  color: Colors.blue,
                  alignment: Alignment.center,
                  child: Text('Popup Menu Box', style: TextStyle(color: Colors.white))
              ),
              itemBuilder: (_) => createPopupMenuStringItem(['1','2','3']),
              onSelected: (val) => print(val),
            )
          ],
        ),
      ),
    );
  }

  List<PopupMenuItem<String>> createPopupMenuStringItem<String>(
      List<String> list) {
    return List.generate(list.length, (index) {
      return PopupMenuItem<String>(
        textStyle: TextStyle(fontSize: 12, color: Colors.black),
        value: list[index],
        height: 40,
        child: Text('${list[index]}'),
      );
    });
  }
}
